<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:java="http://xml.apache.org/xslt/java"
  extension-element-prefixes="java">
  
  <xsl:include href="style.xsl"/>

  <xsl:output method="html"/>  

  <xsl:template name="pageHead">
    <head>
      <title><xsl:call-template name="text"><xsl:with-param name="key">nzdl</xsl:with-param></xsl:call-template></title>
    </head>
    <xsl:call-template name="headScript"/>
  </xsl:template>

  <xsl:template match="pageResponse">
    <xsl:variable name="collName"><xsl:value-of select="ancestor::page/pageRequest/paramList/param[@name='c']/@value"/></xsl:variable>
    <xsl:variable name="serviceName"><xsl:value-of select="service/@name"/></xsl:variable>
    <center>
      <xsl:call-template name="collectionPageBanner">
	<xsl:with-param name="collName" select="$collName"/>
	<xsl:with-param name="pageType">brwse</xsl:with-param>
      </xsl:call-template>
      <p/>
      <xsl:apply-templates select="classifier">
	<xsl:with-param name="collName" select="$collName"/>
	<xsl:with-param name="serviceName" select="$serviceName"/>
      </xsl:apply-templates>
    </center>
  </xsl:template>
  
 
  <!-- recursively process all nodes and documents -->
  
  <xsl:template match="classifier">
    <xsl:param name="collName"/>
    <xsl:param name="serviceName"/>
    <xsl:variable name="cl_name"><xsl:value-of select="@name"/></xsl:variable>
    <xsl:variable name="interleave"><xsl:value-of select="ancestor::page/pageResponse/service/classifierList/classifier[@name=$cl_name]/@documentInterleave"/></xsl:variable>
    <xsl:variable name="orientation"><xsl:value-of select="ancestor::page/pageResponse/service/classifierList/classifier[@name=$cl_name]/@orientation"/></xsl:variable>
    <xsl:variable name='mode'><xsl:value-of select='$orientation'/>-<xsl:value-of select='$interleave'/></xsl:variable>
    <!--<xsl:apply-templates select="." mode='{$mode}'><xsl:with-param name='collName' select='$collName'/><xsl:with-param name='serviceName' select='$serviceName'/></xsl:apply-templates> -->

    <xsl:choose>
      <xsl:when test="$mode='horizontal-true'">
	<xsl:apply-templates select="." mode='horizontal-true'><xsl:with-param name='collName' select='$collName'/><xsl:with-param name='serviceName' select='$serviceName'/></xsl:apply-templates> 
      </xsl:when>
      <xsl:when test="$mode='horizontal-false'">
	<xsl:apply-templates select="." mode='horizontal-false'><xsl:with-param name='collName' select='$collName'/><xsl:with-param name='serviceName' select='$serviceName'/></xsl:apply-templates> 
      </xsl:when>
      <xsl:when test="$mode='vertical-true'">
	<xsl:apply-templates select="." mode='vertical-true'><xsl:with-param name='collName' select='$collName'/><xsl:with-param name='serviceName' select='$serviceName'/></xsl:apply-templates> 
      </xsl:when>
      <xsl:when test="$mode='vertical-false'">
	<xsl:apply-templates select="." mode='vertical-false'><xsl:with-param name='collName' select='$collName'/><xsl:with-param name='serviceName' select='$serviceName'/></xsl:apply-templates> 
      </xsl:when>
    </xsl:choose>
  </xsl:template>
  
  <!-- vertical and interleave = true: process all document and classifier children together, recursively -->
  <xsl:template match="classifier" mode="vertical-true">
    <xsl:param name="collName">coll-name</xsl:param>
    <xsl:param name="serviceName">service-name</xsl:param>
    <table width='537'>
      <xsl:for-each select='classifierNode|documentNode'>
	<tr valign='top'><xsl:apply-templates select='.'><xsl:with-param name='collName' select='$collName'/><xsl:with-param name='serviceName' select='$serviceName'/></xsl:apply-templates></tr>
	<xsl:if test='name()="classifierNode"'>
	  <!--recurse into the children-->
	  <tr valign='top'><td><xsl:text> </xsl:text></td><xsl:apply-templates select='.' mode='process-all-children'><xsl:with-param name='collName' select='$collName'/><xsl:with-param name='serviceName' select='$serviceName'/></xsl:apply-templates></tr>
	</xsl:if>
      </xsl:for-each>
    </table>
    <xsl:call-template name="greenBar"/>
  </xsl:template>
  
  <!--vertical and interleave = false: process all classifier nodes, recursively, then do the document ones separately -->
  <xsl:template match="classifier" mode="vertical-false">
    <xsl:param name="collName">coll-name</xsl:param>
    <xsl:param name="serviceName">service-name</xsl:param>
    <!-- process the nodes and documents separately-->
    <table width='537'>
      <xsl:for-each select='classifierNode'>
	<tr valign='top'><xsl:apply-templates select='.'><xsl:with-param name='collName' select='$collName'/></xsl:apply-templates></tr>
	<tr valign='top'><td><xsl:text> </xsl:text></td><xsl:apply-templates select='.' mode='process-node-children'><xsl:with-param name='collName' select='$collName'/></xsl:apply-templates></tr></xsl:for-each>
    </table>
    <table width='537'>
      <xsl:for-each select='//documentNode'>
	<tr valign='top'><xsl:apply-templates select='.'><xsl:with-param name='collName' select='$collName'/></xsl:apply-templates></tr>
      </xsl:for-each>
    </table>
    <xsl:call-template name="greenBar"/>
  </xsl:template>


  <xsl:template match="classifier" mode="horizontal-true">
    <xsl:param name="collName">coll-name</xsl:param>
    <xsl:param name="serviceName">service-name</xsl:param>
    <!-- process the nodes and documents together -->
    
    <table>
      <tr valign='top'>
	<xsl:for-each select='classifierNode|documentNode'>
	  <xsl:apply-templates select='.'><xsl:with-param name='collName' select='$collName'/><xsl:with-param name='serviceName' select='$serviceName'/></xsl:apply-templates>
	</xsl:for-each>
      </tr>
      <tr valign='top'>
	<xsl:for-each select='classifierNode|documentNode'>
	  <td><xsl:text> </xsl:text></td> <!-- the empty cell for the icon -->
	  <xsl:choose><xsl:when test='name()="classifierNode" and classifierNode|documentNode'>
	      <xsl:apply-templates select='.' mode='process-all-children'><xsl:with-param name='collName' select='$collName'/><xsl:with-param name='serviceName' select='$serviceName'/></xsl:apply-templates>
	    </xsl:when>
	    <xsl:otherwise>
	      <td><xsl:text> </xsl:text></td>
	    </xsl:otherwise>
	  </xsl:choose>
	</xsl:for-each>
      </tr>
    </table>
    <xsl:call-template name="greenBar"/>
  </xsl:template>

  <xsl:template match="classifier" mode="horizontal-false">
    <xsl:param name="collName">coll-name</xsl:param>
    <xsl:param name="serviceName">service-name</xsl:param>
    <!-- process the nodes and documents separately-->
    
    <table width='537'><tr valign='top'>
	<xsl:for-each select='classifierNode'>
	  <xsl:apply-templates select='.'><xsl:with-param name='collName' select='$collName'/><xsl:with-param name='serviceName' select='$serviceName'/></xsl:apply-templates>
	</xsl:for-each></tr>
      <tr valign='top'>
	<xsl:for-each select='classifierNode'>
	  <xsl:apply-templates select='.' mode='process-node-children'><xsl:with-param name='collName' select='$collName'/><xsl:with-param name='serviceName' select='$serviceName'/></xsl:apply-templates></xsl:for-each></tr>
    </table>
    <table width='537'>
      <xsl:for-each select='//documentNode'>
	<tr valign='top'><xsl:apply-templates select='.'><xsl:with-param name='collName' select='$collName'/></xsl:apply-templates></tr>
      </xsl:for-each>
    </table>
    <xsl:call-template name="greenBar"/>
  </xsl:template>

<xsl:template match="documentNode">
<xsl:param name="collName">coll-name</xsl:param>
<xsl:variable name='library' select='ancestor::page/pageExtra/config/library_name'/>
<td><a href="{$library}?a=d&amp;c={$collName}&amp;d={@nodeID}"><img src='interfaces/default/images/book.gif' width='18' height='11' border='0'/></a></td><td><xsl:value-of select="metadataList/metadata[@name='Title']"/></td>
</xsl:template>
<!--
  <xslt:template xmlns:xslt="http://www.w3.org/1999/XSL/Transform" match="documentNode" priority="4">
    <xslt:param name="collName">coll-name</xslt:param>
 
    <xslt:variable name="library" select="ancestor::page/pageExtra/config/library_name" />    <td>
      <a href="{$library}?a=d&amp;c={$collName}&amp;d={@nodeID}">
        <img border="0" height="11" src="interfaces/default/images/book.gif" width="18" /></a>
    </td>
 
    <td>
      <xslt:value-of select="metadataList/metadata[@name='Source']" /></td>
  </xslt:template>
-->
  <!-- icon + title -->
  <xsl:template match="classifierNode">
    <xsl:param name="collName">coll-name</xsl:param>
    <xsl:param name="serviceName">service-name</xsl:param>
    <xsl:variable name="library" select="ancestor::page/pageExtra/config/library_name"/>
    <td><a><xsl:attribute name='href'><xsl:value-of select='$library'/>?a=b&amp;s=<xsl:value-of select='$serviceName'/>&amp;c=<xsl:value-of select='$collName'/>&amp;cl=<xsl:value-of select='@nodeID'/><xsl:if test="classifierNode|documentNode">.pr</xsl:if><xsl:if test="parent::node()[@orientation='horizontal']">&amp;sib=1</xsl:if></xsl:attribute><img src='interfaces/default/images/bshelf.gif' border='0' width='20' height='16' /></a></td><td align='left'><xsl:value-of select="metadataList/metadata[@name='Title']"/></td>
  </xsl:template>
  
  <!-- the title is a link: an alternative template -->
  <!--
  <xsl:template match="classifierNode">
    <xsl:param name="collName">coll-name</xsl:param>
    <xsl:param name="serviceName">service-name</xsl:param>
    <xsl:variable name="library" select="ancestor::page/pageExtra/config/library_name"/>
    <td><a><xsl:attribute name='href'><xsl:value-of select='$library'/>?a=b&amp;s=<xsl:value-of select='$serviceName'/>&amp;c=<xsl:value-of select='$collName'/>&amp;cl=<xsl:value-of select='@nodeID'/><xsl:if test="classifierNode|documentNode">.pr</xsl:if></xsl:attribute><xsl:value-of select="metadataList/metadata[@name='Title']"/></a></td>
  </xsl:template>
  -->

<!-- processing for the recursive bit -->
<!-- if interleave=true, process all child nodes and documents, else just do nodes -->


  <xsl:template match="classifierNode" mode="process-all-children">
    <xsl:param name="collName">coll-name</xsl:param>
    <xsl:param name="serviceName">service-name</xsl:param>
    <td><p/>
    <!-- only do this if there are children -->
    <xsl:if test="classifierNode|documentNode">
      <xsl:choose>
	<xsl:when test='@orientation="vertical"'>
	  <table>  
	    <xsl:for-each select='classifierNode|documentNode'>
	      <tr valign='top'><xsl:apply-templates select='.'><xsl:with-param name='collName' select='$collName'/><xsl:with-param name='serviceName' select='$serviceName'/></xsl:apply-templates></tr>
	      <xsl:if test='name()="classifierNode"'>
		<tr valign='top'><td><xsl:text> </xsl:text></td><xsl:apply-templates select='.' mode='process-all-children'><xsl:with-param name='collName' select='$collName'/></xsl:apply-templates></tr>
	      </xsl:if>	      
	    </xsl:for-each>
	  </table>
	</xsl:when>
	<xsl:otherwise> <!-- horizontal -->
	  <table>
	    <tr valign='top'>
	      <xsl:for-each select='classifierNode|documentNode'>
		<xsl:apply-templates select='.'><xsl:with-param name='collName' select='$collName'/><xsl:with-param name='serviceName' select='$serviceName'/></xsl:apply-templates>
		<xsl:if test='name()="classifierNode"'>
		  <xsl:apply-templates select='.' mode='process-all-children'><xsl:with-param name='collName' select='$collName'/><xsl:with-param name='serviceName' select='$serviceName'/></xsl:apply-templates>
		</xsl:if>
	      </xsl:for-each>
	    </tr>
	  </table>
	</xsl:otherwise>
      </xsl:choose>
    </xsl:if>
    </td>
  </xsl:template>

  <xsl:template match="classifierNode" mode="process-node-children">
    <xsl:param name="collName">coll-name</xsl:param>
    <xsl:param name="serviceName">ClassifierBrowse</xsl:param>
    <td><p/>
      <xsl:if test='classifierNode'><!-- only do this if there are child nodes - netscape craps out at an empty table like <table  /> -->
	<xsl:choose>
	  <xsl:when test='@orientation="vertical"'>
	    <table>
	      <xsl:for-each select='classifierNode'>
		<tr valign='top'><xsl:apply-templates select='.'><xsl:with-param name='collName' select='$collName'/><xsl:with-param name='serviceName' select='$serviceName'/></xsl:apply-templates></tr>
		<tr valign='top'><td><xsl:text> </xsl:text></td><xsl:apply-templates select='.' mode='process-node-children'><xsl:with-param name='collName' select='$collName'/><xsl:with-param name='serviceName' select='$serviceName'/></xsl:apply-templates></tr>
	      </xsl:for-each>
	    </table>
	  </xsl:when>
	  <xsl:otherwise>
	    <table>
	      <tr valign='top'><xsl:apply-templates select='classifierNode'><xsl:with-param name='collName' select='$collName'/><xsl:with-param name='serviceName' select='$serviceName'/></xsl:apply-templates>
		<xsl:apply-templates select='classifierNode' mode='process-node-children'><xsl:with-param name='collName' select='$collName'/></xsl:apply-templates></tr>
	    </table>
	  </xsl:otherwise>
	</xsl:choose> 
      </xsl:if>
    </td>
  </xsl:template>

</xsl:stylesheet>






